# rmtoo-art-html

NAME
DESCRIPTION
HEADER
MIDDLE PART
FOOTER
CSS
CONFIGURATION
SEE ALSO
AUTHOR
COPYRIGHT

## NAME

rmtoo-art-html - requirements management tool: html artifact

## DESCRIPTION

The rmtoo requirment management tool is able to output one topic and all possible subtopics including the containing requirements as a set of HTML documents.

Each HTML page is generated out of three parts: a header, a middle part and a footer. The header and footer are files which are copied into each HTML page and are the same for all pages. The middle part is automatically generated.

## HEADER

The header must include the whole HTML header including the opening html, full head and opening body tags.

The header may also contain the definitions for the css tags which are used in the middle part. See section CSS for more details.

## MIDDLE PART

The middle part is automatically generated. The topic description is used as a base for layout, text and requirements.

## FOOTER

The footer can contain arbritary HTML code. It is copied to the end of each page. At least closing body and html tags must be included.

## CSS

Mostly each element in a requirement has a separate CSS class. Therefore it is possible to format mostly every single bit of a requirement output as wanted. Please consult doc/html/header.html for an example. Here is a list of all special rmtoo CSS classes used by the requirements output. Of course additional standard CSS classes or attributes (like h1, h2, a and so on) can be defined.

| fltext |  | The floating text which is specified in the Text: tag in the topic description.

requirment_end

A separator can be defined here. This ends up a requirement.

dlt_<name>

The tag (key) of mostly all requirements keys can be defined. Example: dlt_description

dlv_<name>

The tag (key) of mostly all requirements keys can be defined. Example: dlv_description

## CONFIGURATION

To configure HTML output, three mandatory fields are needed:
output_directory output directory of the HTML files.
header HTML header file name.
footer HTML footer file name.

## SEE ALSO

rmtoo(7) - overview of rmtoo including all references to available documentation.

## AUTHOR

Written by Andreas Florath (rmtoo@florath.net)

## COPYRIGHT

Copyright © 2010 by flonatel (rmtoo@florath.net). License GPLv3+: GNU GPL version 3 or later